# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
🚚 Rename `DObject` to `File` | [8](https://github.com/laminlabs/lndb-storage/pull/8) | [falexwolf](https://github.com/falexwolf) | 2023-03-24 |
✅ Test streaming here | [6](https://github.com/laminlabs/lndb-storage/pull/6) | [Koncopd](https://github.com/Koncopd) | 2023-03-17 |
♻️ Move the rest of storage code here | [4](https://github.com/laminlabs/lndb-storage/pull/4) | [Koncopd](https://github.com/Koncopd) | 2023-03-14 |
:construction_worker: Update with latest cookiecutter | [5](https://github.com/laminlabs/lndb-storage/pull/5) | [falexwolf](https://github.com/falexwolf) | 2023-03-14 |
🔨 Update storage code | [3](https://github.com/laminlabs/lndb-storage/pull/3) | [Koncopd](https://github.com/Koncopd) | 2023-03-11 |
 🎉 Start moving code from lamindb | [1](https://github.com/laminlabs/lndb-storage/pull/1) | [Koncopd](https://github.com/Koncopd) | 2022-11-20 |
